# Verbarius Clock Russian prototype algorithm

    половина двенадцатого
    тридцать одна минута двенадцатого
    одиннадцать часов тридцать пять минут
    без двадцати полдень
    одиннадцать сорок пять
    без минуты полдень
    двенадцать
    два ровно
    пятнадцать минут третьего
    без пяти три
    без пятидесяти девяти пять =)
    четыре с четвертью
    одна минута шестого
